@@ -20,10 +20,12 @@
 #include <KLocalizedString>
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/surface.h>
+#include <KWindowSystem>
 #include <QGuiApplication>
 #include <QScreen>
 #include <QtCore/qmath.h>
 #include <QPainterPath>
+#include <QX11Info>
 
 #include "QuickEditor.h"
 #include "settings.h"
@@ -91,6 +93,31 @@ QuickEditor::QuickEditor(const QPixmap &thePixmap, KWayland::Client::PlasmaShell
 
     dprI = 1.0 / devicePixelRatioF();
     setGeometry(0, 0, static_cast<int>(mPixmap.width() * dprI), static_cast<int>(mPixmap.height() * dprI));
+
+    if (KWindowSystem::isPlatformX11()) {
+        // Even though we want the quick editor window to be placed at (0, 0) in the native
+        // pixels, we cannot really specify a window position of (0, 0) if HiDPI support is on.
+        //
+        // The main reason for that is that Qt will scale the window position relative to the
+        // upper left corner of the screen where the quick editor is on in order to perform
+        // a conversion from the device-independent coordinates to the native pixels.
+        //
+        // Since (0, 0) in the device-independent pixels may not correspond to (0, 0) in the
+        // native pixels, we use XCB API to place the quick editor window at (0, 0).
+
+        uint16_t mask = 0;
+
+        mask |= XCB_CONFIG_WINDOW_X;
+        mask |= XCB_CONFIG_WINDOW_Y;
+
+        const uint32_t values[] = {
+            /* x */ 0,
+            /* y */ 0,
+        };
+
+        xcb_configure_window(QX11Info::connection(), winId(), mask, values);
+    }
+
     // TODO This is a hack until a better interface is available
     if (plasmashell) {
         using namespace KWayland::Client;
@@ -112,7 +139,7 @@ QuickEditor::QuickEditor(const QPixmap &thePixmap, KWayland::Client::PlasmaShell
                 cropRegion.y() * dprI,
                 cropRegion.width() * dprI,
                 cropRegion.height() * dprI
-            ).intersected(geometry());
+            ).intersected(rect());
         }
         setMouseCursor(QCursor::pos());
     } else {
@@ -490,7 +517,7 @@ void QuickEditor::paintEvent(QPaintEvent*)
     QBrush brush(mPixmap);
     brush.setTransform(QTransform().scale(dprI, dprI));
     painter.setBackground(brush);
-    painter.eraseRect(geometry());
+    painter.eraseRect(rect());
     if (!mSelection.size().isEmpty() || mMouseDragState != MouseState::None) {
         painter.fillRect(mSelection, mStrokeColor);
         const QRectF innerRect = mSelection.adjusted(1, 1, -1, -1);
@@ -723,7 +750,7 @@ void QuickEditor::drawMagnifier(QPainter &painter)
 
 void QuickEditor::drawMidHelpText(QPainter &painter)
 {
-    painter.fillRect(geometry(), mMaskColor);
+    painter.fillRect(rect(), mMaskColor);
     painter.setFont(mMidHelpTextFont);
     QRect textSize = painter.boundingRect(QRect(), Qt::AlignCenter, mMidHelpText);
     QPoint pos((mPrimaryScreenGeo.width() - textSize.width()) / 2 + mPrimaryScreenGeo.x(), (height() - textSize.height()) / 2);
