@@ -116,9 +116,7 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
 
     mStartMode = SpectacleCore::StartMode::Gui;
     mNotify = true;
-    mCopyToClipboard = Settings::copyImageToClipboard();
     qint64 lDelayMsec = 0;
-    QString lFileName = QString();
 
     // are we ask to run in background or dbus mode?
     if (parser->isSet(QStringLiteral("background"))) {
@@ -135,13 +133,6 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
         lDelayMsec = 0;
     }
 
-    if (!(lFileName.isEmpty() || lFileName.isNull())) {
-        if (QDir::isRelativePath(lFileName)) {
-            lFileName = QDir::current().absoluteFilePath(lFileName);
-        }
-        setFilename(lFileName);
-    }
-
     // reset last region if it should not be remembered across restarts
     if(!Settings::alwaysRememberRegion()) {
         Settings::setCropRegion({0, 0, 0, 0});
@@ -150,16 +141,26 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
     switch (mStartMode) {
 
     case StartMode::DBus:
+        mCopyToClipboard = Settings::copyImageToClipboard();
         qApp->setQuitOnLastWindowClosed(false);
+        mCopyToClipboard = Settings::copyImageToClipboard();
         break;
 
     case StartMode::Background: {
+        mCopyToClipboard = false;
         if (parser->isSet(QStringLiteral("nonotify"))) {
             mNotify = false;
         }
 
         if (parser->isSet(QStringLiteral("output"))) {
-            lFileName = parser->value(QStringLiteral("output"));
+            mSaveToOutput = true;
+            QString lFileName = parser->value(QStringLiteral("output"));
+            if (!(lFileName.isEmpty() || lFileName.isNull())) {
+                if (QDir::isRelativePath(lFileName)) {
+                    lFileName = QDir::current().absoluteFilePath(lFileName);
+                }
+                setFilename(lFileName);
+            }
         }
 
         if (parser->isSet(QStringLiteral("delay"))) {
@@ -182,8 +183,17 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
             static_cast<QGuiApplication *>(qApp->instance())->setQuitOnLastWindowClosed(false);
         }
 
-        auto lIncludePointer = Settings::includePointer();
-        auto lIncludeDecorations = Settings::includeDecorations();
+        auto lIncludePointer = false;
+        auto lIncludeDecorations = true;
+
+        if (parser->isSet(QStringLiteral("pointer"))) {
+            lIncludePointer = true;
+        }
+
+        if (parser->isSet(QStringLiteral("no-decoration"))) {
+            lIncludeDecorations = false;
+        }
+
         takeNewScreenshot(lCaptureMode, lDelayMsec, lIncludePointer, lIncludeDecorations);
     }
         break;
@@ -201,6 +211,9 @@ void SpectacleCore::onActivateRequested(QStringList arguments, const QString& /*
                     break;
                 }
                 case Actions::FocusWindow:
+                    if (mMainWindow->isHidden()) {
+                        mMainWindow->show();
+                    }
                     if (mMainWindow->isMinimized()) {
                         mMainWindow->setWindowState(mMainWindow->windowState() & ~Qt::WindowMinimized);
                     }
@@ -288,7 +301,7 @@ void SpectacleCore::screenshotUpdated(const QPixmap &thePixmap)
         if(!mQuickEditor) {
             mQuickEditor = std::make_unique<QuickEditor>(thePixmap, mWaylandPlasmashell);
             connect(mQuickEditor.get(), &QuickEditor::grabDone, this, &SpectacleCore::screenshotUpdated);
-            connect(mQuickEditor.get(), &QuickEditor::grabCancelled, this, &SpectacleCore::screenshotFailed);
+            connect(mQuickEditor.get(), &QuickEditor::grabCancelled, this, &SpectacleCore::screenshotCanceled);
             mQuickEditor->show();
             return;
         } else {
@@ -304,14 +317,17 @@ void SpectacleCore::screenshotUpdated(const QPixmap &thePixmap)
     case StartMode::Background:
     case StartMode::DBus:
         {
-            if (mCopyToClipboard) {
-                lExportManager->doCopyToClipboard(mNotify);
-            } else {
+            if (mSaveToOutput || !mCopyToClipboard || (Settings::autoSaveImage() && !mSaveToOutput)) {
+                mSaveToOutput = Settings::autoSaveImage();
                 QUrl lSavePath = (mStartMode == StartMode::Background && mFileNameUrl.isValid() && mFileNameUrl.isLocalFile()) ?
                     mFileNameUrl : QUrl();
                 lExportManager->doSave(lSavePath, mNotify);
             }
 
+            if (mCopyToClipboard) {
+                lExportManager->doCopyToClipboard(mNotify);
+            }
+
             // if we don't have a Gui already opened, emit allDone
             if (!this->mIsGuiInited) {
                 // if we notify, we emit allDone only if the user either dismissed the notification or pressed
@@ -342,6 +358,15 @@ void SpectacleCore::screenshotUpdated(const QPixmap &thePixmap)
     }
 }
 
+void SpectacleCore::screenshotCanceled()
+{
+    mQuickEditor->hide();
+    mQuickEditor.reset(nullptr);
+    if (mStartMode == StartMode::Gui) {
+        mMainWindow->setScreenshotAndShow(QPixmap());
+    }
+}
+
 void SpectacleCore::screenshotFailed()
 {
     if (ExportManager::instance()->captureMode() == Spectacle::CaptureMode::RectangularRegion && mQuickEditor) {
@@ -359,6 +384,7 @@ void SpectacleCore::screenshotFailed()
         emit allDone();
         return;
     case StartMode::Gui:
+        mMainWindow->screenshotFailed();
         mMainWindow->setScreenshotAndShow(QPixmap());
     }
 }
@@ -390,7 +416,11 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
 
     // a speaking message is prettier than a URL, special case for copy to clipboard and the default pictures location
     const QString &lSavePath = theSavedAt.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash).path();
-    if (mCopyToClipboard) {
+    if (mSaveToOutput) {
+        lNotify->setText(i18n("A screenshot was saved as '%1' to '%2'.", theSavedAt.fileName(), lSavePath));
+        // set to false so it won't show the same message twice
+        mSaveToOutput = false;
+    } else if (mCopyToClipboard) {
         lNotify->setText(i18n("A screenshot was saved to your clipboard."));
     } else if (lSavePath == QStandardPaths::writableLocation(QStandardPaths::PicturesLocation)) {
         lNotify->setText(i18nc("Placeholder is filename", "A screenshot was saved as '%1' to your Pictures folder.", theSavedAt.fileName()));
@@ -398,7 +428,7 @@ void SpectacleCore::doNotify(const QUrl &theSavedAt)
         lNotify->setText(i18n("A screenshot was saved as '%1' to '%2'.", theSavedAt.fileName(), lSavePath));
     }
 
-    if (!mCopyToClipboard) {
+    if (!theSavedAt.isEmpty()) {
         lNotify->setUrls({theSavedAt});
         lNotify->setDefaultAction(i18nc("Open the screenshot we just saved", "Open"));
         connect(lNotify, QOverload<uint>::of(&KNotification::activated), this, [this, theSavedAt](uint index) {
@@ -446,7 +476,9 @@ void SpectacleCore::populateCommandLineParser(QCommandLineParser *lCmdLineParser
         {{QStringLiteral("d"), QStringLiteral("delay")},             i18n("In background mode, delay before taking the shot (in milliseconds)"), QStringLiteral("delayMsec")},
         {{QStringLiteral("c"), QStringLiteral("clipboard")},         i18n("In background mode, copy screenshot to clipboard")},
         {{QStringLiteral("w"), QStringLiteral("onclick")},           i18n("Wait for a click before taking screenshot. Invalidates delay")},
-        {{QStringLiteral("i"), QStringLiteral("new-instance")},      i18n("Starts a new GUI instance of spectacle without registering to DBus")}
+        {{QStringLiteral("i"), QStringLiteral("new-instance")},      i18n("Starts a new GUI instance of spectacle without registering to DBus")},
+        {{QStringLiteral("p"), QStringLiteral("pointer")},           i18n("In background mode, include pointer in the screenshot")},
+        {{QStringLiteral("e"),QStringLiteral("no-decoration")},     i18n("In background mode, exclude decorations in the screenshot")},
     });
 }
 
