@@ -73,6 +73,7 @@ class SpectacleCore: public QObject
     void takeNewScreenshot(Spectacle::CaptureMode theCaptureMode, int theTimeout, bool theIncludePointer, bool theIncludeDecorations);
     void showErrorMessage(const QString &theErrString);
     void screenshotUpdated(const QPixmap &thePixmap);
+    void screenshotCanceled();
     void screenshotFailed();
     void doStartDragAndDrop();
     void doNotify(const QUrl &theSavedAt);
@@ -95,5 +96,6 @@ class SpectacleCore: public QObject
     EditorPtr     mQuickEditor;
     bool          mIsGuiInited;
     bool          mCopyToClipboard;
+    bool          mSaveToOutput;
     KWayland::Client::PlasmaShell *mWaylandPlasmashell;
 };
